MethodChannelFlutterRingtoneManager class

An implementation of FlutterRingtoneManagerPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
playAlarm() → FutureOr<void>
override
playAudioAsset(String assetPath) → Future<FutureOr<void>>
override
playIosSystemSoundByID(int id) → FutureOr<void>
override
playNotification() → FutureOr<void>
override
playRingtone() → FutureOr<void>
override
stop() → FutureOr<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited