FlutterRingtoneManagerPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterRingtoneManagerPlatform
Implementers

Constructors

FlutterRingtoneManagerPlatform()
Constructs a FlutterRingtoneManagerPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
playAlarm() → FutureOr<void>
playAudioAsset(String assetPath) → FutureOr<void>
playIosSystemSoundByID(int id) → FutureOr<void>
playNotification() → FutureOr<void>
playRingtone() → FutureOr<void>
stop() → FutureOr<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterRingtoneManagerPlatform
The default instance of FlutterRingtoneManagerPlatform to use.
getter/setter pair