FlutterRingtoneManagerWeb class

A web implementation of the FlutterRingtoneManagerPlatform of the FlutterRingtoneManager plugin.

Inheritance

Constructors

FlutterRingtoneManagerWeb()
Constructs a FlutterRingtoneManagerWeb

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
playAlarm() → FutureOr<void>
inherited
playAudioAsset(String assetPath) → FutureOr<void>
inherited
playIosSystemSoundByID(int id) → FutureOr<void>
inherited
playNotification() → FutureOr<void>
inherited
playRingtone() → FutureOr<void>
inherited
stop() → FutureOr<void>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void